# DevSecOps CLI
This tool assists DevSecOps engineers to perform the achiev the followings:
- Configuration management
    - Paramaters
    - Secrets
    - Templates
- Package management
- Release management
- Infrastructure as Code
- Provision resources on the public clouds
- Deploy releases
- Security testing (SAST/DAST)
